/**
 * This export is a variant of the quickjs WASM library:
 * ### [@jitl/quickjs-node-esm-debug-sync-wasm](https://github.com/justjake/quickjs-emscripten/blob/main/doc/packages/@jitl/quickjs-node-esm-debug-sync-wasm/README.md)
 *
 * Node.js ESModule
 *
 * | Variable            |    Setting                     |    Description    |
 * | --                  | --                             | --                |
 * | releaseMode         | debug | Enables assertions and memory sanitizers. Try to run your tests against debug variants, in addition to your preferred production variant, to catch more bugs. |
 * | syncMode            | sync | The default, normal build. Note that both variants support regular async functions. |
 * | moduleSystem        | esm | This variant exports an ESModule, which is standardized for browsers and more modern browser-like environments. It cannot be imported from CommonJS without shenanigans. |
 * | emscriptenInclusion | wasm | Has a separate .wasm file. May offer better caching in your browser, and reduces the size of your JS bundle. If you have issues, try a 'singlefile' variant. |
 *
 */
declare const variant: {
    readonly type: "sync";
    readonly importFFI: () => Promise<typeof import("./ffi.js").QuickJSFFI | (new (module: import("@jitl/quickjs-ffi-types").QuickJSEmscriptenModule) => import("@jitl/quickjs-ffi-types").QuickJSFFI)>;
    readonly importModuleLoader: () => Promise<import("@jitl/quickjs-ffi-types").EmscriptenModuleLoader<import("@jitl/quickjs-ffi-types").QuickJSEmscriptenModule> | {
        default: import("@jitl/quickjs-ffi-types").EmscriptenModuleLoader<import("@jitl/quickjs-ffi-types").QuickJSEmscriptenModule>;
    } | {
        default: {
            default: import("@jitl/quickjs-ffi-types").EmscriptenModuleLoader<import("@jitl/quickjs-ffi-types").QuickJSEmscriptenModule>;
        };
    }>;
};
export default variant;
